@@ -4,7 +4,7 @@
 *
 * Checks plot-parameter data read from plot-parameter file.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -36,8 +36,8 @@ void CheckParamData ( void )
        index_bin_values, index_bin_refs, icount, i, j, k;
    unsigned int size;
    char *pchar, *string;
-   extern char symbol_string[];   /* symbol-specification characters */
-   extern char color_string[];    /* color-specification characters */
+   extern char symbol_string[];   /* symbol-specification characters "ldcCtTsSiIpPhH+xra" */
+   extern char color_string[];    /* color-specification characters "kaswrylqbfmogtnpx" */
    const char *error_str[] =
       { "Window size greater than screen size.",
         "Invalid or missing axis_type parameter.",
@@ -47,7 +47,7 @@ void CheckParamData ( void )
         "Only points plot_type compatible with semilogy axis_type.",
         "Only points plot_type compatible with loglog axis_type.",
         "Only points plot_type compatible with polar axis_type.",
-        "Only points, mesh, and contour plot_type's\ncompatible with 3d axis_type.",
+        "Only points, mesh, contour, and color plot_type's\ncompatible with 3d axis_type.",
         "Invalid or missing plot_style parameter.",
         "Invalid axis_scale parameter.",
         "Invalid grid parameter.",
@@ -188,7 +188,8 @@ void CheckParamData ( void )
       else if ( strcmp(p_plot_param->axis_type, "3d") == 0 &&
                 strcmp(&plot_types[index_plot_types], "points")  != 0 &&
                 strcmp(&plot_types[index_plot_types], "mesh")    != 0 &&
-                strcmp(&plot_types[index_plot_types], "contour") != 0 )
+                strcmp(&plot_types[index_plot_types], "contour") != 0 &&
+                strcmp(&plot_types[index_plot_types], "color")   != 0 )
          {
          ErrorDialog(error_str[8]);
          FreeMemory();
@@ -239,7 +240,8 @@ void CheckParamData ( void )
             }
          }
 
-      else if ( strcmp(&plot_types[index_plot_types], "color") == 0 )
+      else if ( strcmp(&plot_types[index_plot_types], "color") == 0 &&
+                strcmp(p_plot_param->axis_type, "linear") == 0 )
          {
          if ( styleflags[iplot-1] != 8 &&
               styleflags[iplot-1] != 9 )
@@ -250,6 +252,20 @@ void CheckParamData ( void )
             }
          }
 
+      else if ( strcmp(&plot_types[index_plot_types], "mesh") == 0 )
+         {
+         if ( styleflags[iplot-1] != 2 &&
+              styleflags[iplot-1] != 4 &&
+              styleflags[iplot-1] != 5 &&
+              styleflags[iplot-1] != 6 &&
+              styleflags[iplot-1] != 7 )
+            {
+            ErrorDialog(error_str[9]);
+            FreeMemory();
+            exit(1);
+            }
+         }
+
       else if ( strcmp(&plot_types[index_plot_types], "contour") == 0 &&
                 strcmp(p_plot_param->axis_type, "3d") == 0 )
          {
@@ -264,13 +280,10 @@ void CheckParamData ( void )
             }
          }
 
-      else if ( strcmp(&plot_types[index_plot_types], "mesh") == 0 )
+      else if ( strcmp(&plot_types[index_plot_types], "color") == 0 &&
+                strcmp(p_plot_param->axis_type, "3d") == 0 )
          {
-         if ( styleflags[iplot-1] != 2 &&
-              styleflags[iplot-1] != 4 &&
-              styleflags[iplot-1] != 5 &&
-              styleflags[iplot-1] != 6 &&
-              styleflags[iplot-1] != 7 )
+         if ( styleflags[iplot-1] != 7 )
             {
             ErrorDialog(error_str[9]);
             FreeMemory();
