@@ -4,7 +4,7 @@
 *
 * Finds minimum and maximum values of 3d-plot data.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -31,9 +31,11 @@
 void DataMinMax3d ( void )
    {
    /* Declare variables */
-   int i, j, iplot, nplots, index_plot_types, ipoints, imesh, icontour,
-       npts, nx, ny, index, xindex_mesh, yindex_mesh, zindex_mesh,
-       xindex_contour, yindex_contour, zindex_contour,
+   int i, j, iplot, nplots, index_plot_types,
+       npts, nx, ny, index, ipoints,
+       imesh, xindex_mesh, yindex_mesh, zindex_mesh,
+       icontour, xindex_contour, yindex_contour, zindex_contour,
+       icolor, xindex_color, yindex_color, zindex_color,
        nlines, nsymbols;
    double xmin, xmax, ymin, ymax, zmin, zmax, line_coords[6], symbol_coords[3];
    char line[NLINE];
@@ -62,9 +64,13 @@ void DataMinMax3d ( void )
    xindex_contour = 0;
    yindex_contour = 0;
    zindex_contour = 0;
+   xindex_color = 0;
+   yindex_color = 0;
+   zindex_color = 0;
    ipoints = 0;
    imesh = 0;
    icontour = 0;
+   icolor = 0;
    for ( iplot=1; iplot<=nplots; iplot++ )
       {
       if ( strcmp(&plot_types[index_plot_types], "points") == 0 )
@@ -156,6 +162,37 @@ void DataMinMax3d ( void )
          zindex_contour = zindex_contour + nx*ny;
          }
 
+      else if ( strcmp(&plot_types[index_plot_types], "color") == 0 )
+         {
+         icolor++;
+
+         nx = nxcolor[icolor-1];
+         if ( xcolor[xindex_color] < xmin )
+            xmin = xcolor[xindex_color];
+         if ( xcolor[xindex_color+nx-1] > xmax )
+            xmax = xcolor[xindex_color+nx-1];
+
+         ny = nycolor[icolor-1];
+         if ( ycolor[yindex_color] < ymin )
+            ymin = ycolor[yindex_color];
+         if ( ycolor[yindex_color+ny-1] > ymax )
+            ymax = ycolor[yindex_color+ny-1];
+
+         for ( i=1; i<=nx; i++ )
+            for ( j=1; j<=ny; j++ )
+               {
+               if ( zcolor[zindex_color+ny*(i-1)+j-1] < zmin )
+                  zmin = zcolor[zindex_color+ny*(i-1)+j-1];
+               if ( zcolor[zindex_color+ny*(i-1)+j-1] > zmax )
+                  zmax = zcolor[zindex_color+ny*(i-1)+j-1];
+               }
+
+         xindex_color = xindex_color + nx;
+         yindex_color = yindex_color + ny;
+         zindex_color = zindex_color + nx*ny;
+         }
+
+
       /* Increment indices */
       index_plot_types = index_plot_types + 10;
       }
