@@ -4,7 +4,7 @@
 *
 * Draws graph.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -46,9 +46,9 @@ void DrawGraph ( void )
          AxesEqual(1);
 
       /* Draw Plot */
-      DrawGrid();
+      DrawGrid2d();
       DrawGridLog();
-      PlotData();
+      PlotData2d();
       if ( strcmp(p_plot_param->axis_type, "linear") == 0 )
          {
          PlotRectangles();
@@ -56,7 +56,7 @@ void DrawGraph ( void )
          }
       PlotLines();
       PlotSymbols();
-      DrawTickLabels();
+      DrawTickLabels2d();
       DrawTickLabelsLog();
       DrawAxisLabels();
       DrawLegend();
