@@ -4,7 +4,7 @@
 *
 * Draws legend.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -31,7 +31,7 @@
 void DrawLegend ( void )
    {
    /* Declare variables */
-   int i, iplot, nplots, nlines, index_plot_types, index, anchor_text;
+   int i, iplot, ifunc, nplots, nlines, index_plot_types, imesh, icontour, index, anchor_text;
    unsigned int size, nchar;
    long int file_position, file_position_1;
    double x, y, x1, y1, x2, y2, x1_box, y1_box, x2_box, y2_box,
@@ -43,7 +43,9 @@ void DrawLegend ( void )
    double dy_bar[] = { 0.0, 6.0, 0.0 };
    char line[NLINE], *string, *legend_str=NULL, anchor[10], *pchar,
         legend_coords_flag[4];
-   extern char color_string[];   /* color-specification characters */
+   extern char symbol_string1[];   /* symbol-specification characters "cCtTsSiIpPhH" */
+   extern char symbol_string2[];   /* symbol-specification characters "+xra" */
+   extern char color_string[];     /* color-specification characters "kaswrylqbfmogtnpx" */
    const char *error_str[] =
       { "Invalid or incomplete legend coordinates.",
         "Legend anchor not found.",
@@ -324,6 +326,8 @@ void DrawLegend ( void )
    /* Draw symbols */
    nplots = p_plot_param->nplots;
    index_plot_types = 0;
+   imesh = 0;
+   icontour = 0;
    for ( iplot=1; iplot<=nplots; iplot++ )
       {
       if ( strcmp(&plot_types[index_plot_types], "points")    == 0 ||
@@ -355,138 +359,29 @@ void DrawLegend ( void )
             }
 
 
-         /* Draw circles */
-         else if ( stylechar1[iplot-1] == 'c' || stylechar1[iplot-1] == 'C' )
+         /* Draw symbols in symbol_string1 ("cCtTsSiIpPhH") */
+         else if ( (pchar = strchr(symbol_string1, stylechar1[iplot-1])) != NULL )
             {
+            ifunc = pchar - symbol_string1;
             for ( i=1; i<=3; i++ )
                {
                x = xanchor_symbol + 10.0 + (i-1)*20.0;
                y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawCircle(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                          stylesizes[iplot-1]);
+               symbol_func1[ifunc](x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+                                   stylesizes[iplot-1]);
                }
             }
 
 
-         /* Draw triangles */
-         else if ( stylechar1[iplot-1] == 't' || stylechar1[iplot-1] == 'T' )
+         /* Draw symbols in symbol_string2 ("+xra") */
+         else if ( (pchar = strchr(symbol_string2, stylechar1[iplot-1])) != NULL )
             {
+            ifunc = pchar - symbol_string2;
             for ( i=1; i<=3; i++ )
                {
                x = xanchor_symbol + 10.0 + (i-1)*20.0;
                y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawTriangle(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                            stylesizes[iplot-1]);
-               }
-            }
-
-
-         /* Draw squares */
-         else if ( stylechar1[iplot-1] == 's' || stylechar1[iplot-1] == 'S' )
-            {
-            for ( i=1; i<=3; i++ )
-               {
-               x = xanchor_symbol + 10.0 + (i-1)*20.0;
-               y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawSquare(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                          stylesizes[iplot-1]);
-               }
-            }
-
-
-         /* Draw diamonds */
-         else if ( stylechar1[iplot-1] == 'i' || stylechar1[iplot-1] == 'I' )
-            {
-            for ( i=1; i<=3; i++ )
-               {
-               x = xanchor_symbol + 10.0 + (i-1)*20.0;
-               y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawDiamond(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                           stylesizes[iplot-1]);
-               }
-            }
-
-
-         /* Draw pentagons */
-         else if ( stylechar1[iplot-1] == 'p' || stylechar1[iplot-1] == 'P' )
-            {
-            for ( i=1; i<=3; i++ )
-               {
-               x = xanchor_symbol + 10.0 + (i-1)*20.0;
-               y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawPentagon(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                            stylesizes[iplot-1]);
-               }
-            }
-
-
-         /* Draw hexagons */
-         else if ( stylechar1[iplot-1] == 'h' || stylechar1[iplot-1] == 'H' )
-            {
-            for ( i=1; i<=3; i++ )
-               {
-               x = xanchor_symbol + 10.0 + (i-1)*20.0;
-               y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawHexagon(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                           stylesizes[iplot-1]);
-               }
-            }
-
-
-         /* Draw +'s */
-         else if ( stylechar1[iplot-1] == '+' )
-            {
-            for ( i=1; i<=3; i++ )
-               {
-               x = xanchor_symbol + 10.0 + (i-1)*20.0;
-               y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawPlus(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
-               }
-            }
-
-
-         /* Draw 's */
-         else if ( stylechar1[iplot-1] == 'x' )
-            {
-            for ( i=1; i<=3; i++ )
-               {
-               x = xanchor_symbol + 10.0 + (i-1)*20.0;
-               y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawX(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
-               }
-            }
-
-
-         /* Draw stars */
-         else if ( stylechar1[iplot-1] == 'r' )
-            {
-            for ( i=1; i<=3; i++ )
-               {
-               x = xanchor_symbol + 10.0 + (i-1)*20.0;
-               y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawStar(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
-               }
-            }
-
-
-         /* Draw asterisks */
-         else if ( stylechar1[iplot-1] == 'a' )
-            {
-            for ( i=1; i<=3; i++ )
-               {
-               x = xanchor_symbol + 10.0 + (i-1)*20.0;
-               y = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
-
-               DrawAsterisk(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+               symbol_func2[ifunc](x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
                }
             }
 
@@ -513,6 +408,7 @@ void DrawLegend ( void )
 
       else if ( strcmp(&plot_types[index_plot_types], "mesh") == 0 )
          {
+         imesh++;
          x1 = xanchor_symbol;
          y1 = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
          x2 = xanchor_symbol + 60.0;
@@ -523,20 +419,21 @@ void DrawLegend ( void )
             if ( (pchar = strchr(color_string, stylechar1[iplot-1])) != NULL )
                {
                index = pchar - &color_string[0];
-               DrawMesh(x1, y1, x2, y2, color_rgba[index], styleflags[iplot-1]);
+               DrawMesh(x1, y1, x2, y2, color_rgba[index], meshcolors[imesh-1], styleflags[iplot-1]);
                }
             }
 
          else if ( styleflags[iplot-1] == 5 || styleflags[iplot-1] == 6 )
-            DrawMesh(x1, y1, x2, y2, stylecolor1[iplot-1], styleflags[iplot-1]);
+            DrawMesh(x1, y1, x2, y2, stylecolor1[iplot-1], meshcolors[imesh-1], styleflags[iplot-1]);
 
          else if ( styleflags[iplot-1] == 7 )
-            DrawMesh(x1, y1, x2, y2, alphacolor[iplot-1], styleflags[iplot-1]);
+            DrawMesh(x1, y1, x2, y2, alphacolor[iplot-1], meshcolors[imesh-1], styleflags[iplot-1]);
          }
 
 
       else if ( strcmp(&plot_types[index_plot_types], "contour") == 0 )
          {
+         icontour++;
          x1 = xanchor_symbol;
          y1 = yanchor_symbol + yinc1*(iplot - 1) + yinc2;
          x2 = xanchor_symbol + 60.0;
@@ -548,20 +445,20 @@ void DrawLegend ( void )
             if ( (pchar = strchr(color_string, stylechar1[iplot-1])) != NULL )
                {
                index = pchar - &color_string[0];
-               DrawContour(x1, y1, x2, y2, color_rgba[index], styleflags[iplot-1]);
+               DrawContour(x1, y1, x2, y2, color_rgba[index], 0x00000000, styleflags[iplot-1]);
                }
             }
 
          else if ( styleflags[iplot-1] == 3 )
             {
             /* 2d contour plot */
-            DrawContour(x1, y1, x2, y2, stylecolor1[iplot-1], styleflags[iplot-1]);
+            DrawContour(x1, y1, x2, y2, stylecolor1[iplot-1], 0x00000000, styleflags[iplot-1]);
             }
 
          else if ( styleflags[iplot-1] == 7 )
             {
             /* 2d contour plot */
-            DrawContour(x1, y1, x2, y2, color_rgba[3], styleflags[iplot-1]);
+            DrawContour(x1, y1, x2, y2, color_rgba[3], 0x00000000, styleflags[iplot-1]);
             }
 
          else if ( styleflags[iplot-1] == 2 || styleflags[iplot-1] == 4 )
@@ -570,14 +467,14 @@ void DrawLegend ( void )
             if ( (pchar = strchr(color_string, stylechar1[iplot-1])) != NULL )
                {
                index = pchar - &color_string[0];
-               DrawContour(x1, y1, x2, y2, color_rgba[index], styleflags[iplot-1]);
+               DrawContour(x1, y1, x2, y2, color_rgba[index], contourcolors[icontour-1], styleflags[iplot-1]);
                }
             }
 
          else if ( styleflags[iplot-1] == 5 || styleflags[iplot-1] == 6 )
             {
             /* 3d contour plot */
-            DrawContour(x1, y1, x2, y2, stylecolor1[iplot-1], styleflags[iplot-1]);
+            DrawContour(x1, y1, x2, y2, stylecolor1[iplot-1], contourcolors[icontour-1], styleflags[iplot-1]);
             }
          }
 
