@@ -22,7 +22,7 @@
 *
 * Functions draw lines and plot symbols.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -218,6 +218,7 @@ void DrawCircle ( double x, double y, guint32 fill_color_rgba,
    else
       {
       r = 0.5*size;
+
       circle = gnome_canvas_item_new(group,
                                      GNOME_TYPE_CANVAS_ELLIPSE,
                                      "x1", x - r,
@@ -246,11 +247,11 @@ void DrawTriangle ( double x, double y, guint32 fill_color_rgba,
       return;
    else
       {
-      r = 0.5*size;
-      dx = 0.433012701*size;
-      dy = 0.25*size;
-      points = gnome_canvas_points_new(3);
+      r = 0.666666667*size;
+      dx = 0.577350269*size;
+      dy = 0.333333333*size;
 
+      points = gnome_canvas_points_new(3);
       points->coords[0] = x;
       points->coords[1] = y - r;
       points->coords[2] = x - dx;
@@ -275,7 +276,7 @@ void DrawSquare ( double x, double y, guint32 fill_color_rgba,
                   guint32 outline_color_rgba, unsigned int size )
    {
    /* Declare variables */
-   double r;
+   double dx, dy;
    GnomeCanvasItem *square;
 
 
@@ -284,13 +285,15 @@ void DrawSquare ( double x, double y, guint32 fill_color_rgba,
       return;
    else
       {
-      r = 0.5*size;
+      dx = 0.5*size;
+      dy = 0.5*size;
+
       square = gnome_canvas_item_new(group,
                                      GNOME_TYPE_CANVAS_RECT,
-                                     "x1", x - r,
-                                     "x2", x + r,
-                                     "y1", y - r,
-                                     "y2", y + r,
+                                     "x1", x - dx,
+                                     "x2", x + dx,
+                                     "y1", y - dy,
+                                     "y2", y + dy,
                                      "fill_color_rgba", fill_color_rgba,
                                      "outline_color_rgba", outline_color_rgba,
                                      "width_pixels", 1,
@@ -314,8 +317,8 @@ void DrawDiamond ( double x, double y, guint32 fill_color_rgba,
    else
       {
       r = 0.707106781*size;
-      points = gnome_canvas_points_new(4);
 
+      points = gnome_canvas_points_new(4);
       points->coords[0] = x;
       points->coords[1] = y - r;
       points->coords[2] = x - r;
@@ -352,13 +355,13 @@ void DrawPentagon ( double x, double y, guint32 fill_color_rgba,
       return;
    else
       {
-      r = 0.5*size;
-      dx1 = 0.475528258*size;
-      dx2 = 0.293892626*size;
-      dy1 = 0.154508497*size;
-      dy2 = 0.404508497*size;
-      points = gnome_canvas_points_new(5);
+      r = 0.618033988*size;
+      dx1 = 0.587785252*size;
+      dy1 = 0.190983005*size;
+      dx2 = 0.363271264*size;
+      dy2 = 0.5*size;
 
+      points = gnome_canvas_points_new(5);
       points->coords[0] = x;
       points->coords[1] = y - r;
       points->coords[2] = x - dx1;
@@ -397,11 +400,11 @@ void DrawHexagon ( double x, double y, guint32 fill_color_rgba,
       return;
    else
       {
-      r = 0.5*size;
-      dx = 0.25*size;
-      dy = 0.433012701*size;
-      points = gnome_canvas_points_new(6);
+      r = 0.577350269*size;
+      dx = 0.288675134*size;
+      dy = 0.5*size;
 
+      points = gnome_canvas_points_new(6);
       points->coords[0]  = x - dx;
       points->coords[1]  = y - dy;
       points->coords[2]  = x - r;
@@ -441,9 +444,9 @@ void DrawPlus ( double x, double y, guint32 fill_color_rgba, unsigned int size )
       return;
    else
       {
-      r = 0.5*size;
-      points = gnome_canvas_points_new(2);
+      r = 0.707106781*size;
 
+      points = gnome_canvas_points_new(2);
       points->coords[0] = x;
       points->coords[1] = y - r;
       points->coords[2] = x;
@@ -476,7 +479,7 @@ void DrawPlus ( double x, double y, guint32 fill_color_rgba, unsigned int size )
 void DrawX ( double x, double y, guint32 fill_color_rgba, unsigned int size )
    {
    /* Declare variables */
-   double r;
+   double dx, dy;
    GnomeCanvasItem *line;
    GnomeCanvasPoints *points;
 
@@ -486,13 +489,14 @@ void DrawX ( double x, double y, guint32 fill_color_rgba, unsigned int size )
       return;
    else
       {
-      r = 0.353553390*size;
-      points = gnome_canvas_points_new(2);
+      dx = 0.5*size;
+      dy = 0.5*size;
 
-      points->coords[0] = x + r;
-      points->coords[1] = y - r;
-      points->coords[2] = x - r;
-      points->coords[3] = y + r;
+      points = gnome_canvas_points_new(2);
+      points->coords[0] = x - dx;
+      points->coords[1] = y - dy;
+      points->coords[2] = x + dx;
+      points->coords[3] = y + dy;
 
       line = gnome_canvas_item_new(group,
                                    GNOME_TYPE_CANVAS_LINE,
@@ -501,10 +505,10 @@ void DrawX ( double x, double y, guint32 fill_color_rgba, unsigned int size )
                                    "width_pixels", 1,
                                    NULL);
 
-      points->coords[0] = x - r;
-      points->coords[1] = y - r;
-      points->coords[2] = x + r;
-      points->coords[3] = y + r;
+      points->coords[0] = x + dx;
+      points->coords[1] = y - dy;
+      points->coords[2] = x - dx;
+      points->coords[3] = y + dy;
 
       line = gnome_canvas_item_new(group,
                                    GNOME_TYPE_CANVAS_LINE,
@@ -531,13 +535,13 @@ void DrawStar ( double x, double y, guint32 fill_color_rgba, unsigned int size )
       return;
    else
       {
-      r = 0.5*size;
-      dx1 = 0.475528258*size;
-      dx2 = 0.293892626*size;
-      dy1 = 0.154508497*size;
-      dy2 = 0.404508497*size;
-      points = gnome_canvas_points_new(3);
+      r = 0.618033988*size;
+      dx1 = 0.587785252*size;
+      dy1 = 0.190983005*size;
+      dx2 = 0.363271264*size;
+      dy2 = 0.5*size;
 
+      points = gnome_canvas_points_new(3);
       points->coords[0] = x;
       points->coords[1] = y - r;
       points->coords[2] = x;
@@ -598,11 +602,11 @@ void DrawAsterisk ( double x, double y, guint32 fill_color_rgba, unsigned int si
       return;
    else
       {
-      r  = 0.5*size;
-      dx = 0.433012701*size;
-      dy = 0.25*size;
-      points = gnome_canvas_points_new(2);
+      r = 0.577350269*size;
+      dx = 0.5*size;
+      dy = 0.288675134*size;
 
+      points = gnome_canvas_points_new(2);
       points->coords[0] = x;
       points->coords[1] = y - r;
       points->coords[2] = x;
@@ -666,7 +670,7 @@ void DrawBar ( double x1, double y1, double x2, double y2,
 
 
 void DrawMesh ( double x1, double y1, double x2, double y2,
-                guint32 fill_color_rgba, int flag )
+                guint32 fill_color_rgba, guint32 outline_color_rgba, int flag )
    {
    /* Declare variables */
    int i;
@@ -686,7 +690,7 @@ void DrawMesh ( double x1, double y1, double x2, double y2,
                                         "y1", y1 - 6.0,
                                         "y2", y2 + 6.0,
                                         "fill_color_rgba", fill_color_rgba,
-                                        "outline_color_rgba", 0x000000FF,
+                                        "outline_color_rgba", outline_color_rgba,
                                         "width_pixels", 1,
                                         NULL);
       }
@@ -704,7 +708,7 @@ void DrawMesh ( double x1, double y1, double x2, double y2,
                                            "y1", y1 - 6.0,
                                            "y2", y2 + 6.0,
                                            "fill_color_rgba", fill_color[i-1],
-                                           "outline_color_rgba", 0x000000FF,
+                                           "outline_color_rgba", outline_color_rgba,
                                            "width_pixels", 1,
                                            NULL);
          }
@@ -722,7 +726,7 @@ void DrawMesh ( double x1, double y1, double x2, double y2,
    line = gnome_canvas_item_new(group,
                                 GNOME_TYPE_CANVAS_LINE,
                                 "points", points,
-                                "fill_color_rgba", 0x000000FF,
+                                "fill_color_rgba", outline_color_rgba,
                                 "width_pixels", 1,
                                 NULL);
 
@@ -738,7 +742,7 @@ void DrawMesh ( double x1, double y1, double x2, double y2,
       line = gnome_canvas_item_new(group,
                                    GNOME_TYPE_CANVAS_LINE,
                                    "points", points,
-                                   "fill_color_rgba", 0x000000FF,
+                                   "fill_color_rgba", outline_color_rgba,
                                    "width_pixels", 1,
                                    NULL);
       }
@@ -748,7 +752,7 @@ void DrawMesh ( double x1, double y1, double x2, double y2,
 
 
 void DrawContour ( double x1, double y1, double x2, double y2,
-                   guint32 fill_color_rgba, int flag )
+                   guint32 fill_color_rgba, guint32 outline_color_rgba, int flag )
    {
    /* Declare variables */
    GnomeCanvasItem *rectangle, *ellipse1, *ellipse2;
@@ -763,7 +767,7 @@ void DrawContour ( double x1, double y1, double x2, double y2,
                                         "y1", y1 - 6.0,
                                         "y2", y2 + 6.0,
                                         "fill_color_rgba", fill_color_rgba,
-                                        "outline_color_rgba", 0x000000FF,
+                                        "outline_color_rgba", fill_color_rgba,
                                         "width_pixels", 1,
                                         NULL);
 
@@ -821,27 +825,14 @@ void DrawContour ( double x1, double y1, double x2, double y2,
       /* 3d contour plot */
       gnome_canvas_item_set(ellipse1,
                             "fill_color_rgba", 0x00000000,
-                            "outline_color_rgba", 0x000000FF,
+                            "outline_color_rgba", outline_color_rgba,
                             NULL);
 
       gnome_canvas_item_set(ellipse2,
                             "fill_color_rgba", 0x00000000,
-                            "outline_color_rgba", 0x000000FF,
+                            "outline_color_rgba", outline_color_rgba,
                             NULL);
       }
-
-
-   /* Draw rectangle */
-   rectangle = gnome_canvas_item_new(group,
-                                     GNOME_TYPE_CANVAS_RECT,
-                                     "x1", x1,
-                                     "x2", x2,
-                                     "y1", y1 - 6.0,
-                                     "y2", y2 + 6.0,
-                                     "fill_color_rgba", 0x00000000,
-                                     "outline_color_rgba", 0x000000FF,
-                                     "width_pixels", 1,
-                                     NULL);
    }
 
 
@@ -864,7 +855,7 @@ void DrawColorPlot ( double x1, double y1, double x2, double y2 )
                        { -1.9407e-02,  3.8980e-17, -1.9407e-02 } },
           xi[61], yi[13], zi[61][13], zinterp, zmin, zmax, zscale, fraction;
    GdkPixbuf *pixbuf;
-   GnomeCanvasItem *pixbuf_item, *rectangle;
+   GnomeCanvasItem *pixbuf_item;
 
 
    /* Normalize values of x and y */
@@ -909,24 +900,11 @@ void DrawColorPlot ( double x1, double y1, double x2, double y2 )
    pixbuf_item = gnome_canvas_item_new(group,
                                        GNOME_TYPE_CANVAS_PIXBUF,
                                        "pixbuf", pixbuf,
-                                       "x", x1,
-                                       "y", y1 + 6.0,
-                                       "anchor", GTK_ANCHOR_SOUTH_WEST,
+                                       "x", (x1 + x2)/2.0,
+                                       "y", (y1 + y2)/2.0,
+                                       "anchor", GTK_ANCHOR_CENTER,
                                        NULL);
 
-
-   /* Draw rectangle */
-   rectangle = gnome_canvas_item_new(group,
-                                     GNOME_TYPE_CANVAS_RECT,
-                                     "x1", x1,
-                                     "x2", x2,
-                                     "y1", y1 - 6.0,
-                                     "y2", y2 + 6.0,
-                                     "fill_color_rgba", 0x00000000,
-                                     "outline_color_rgba", 0x000000FF,
-                                     "width_pixels", 1,
-                                     NULL);
-
    g_object_unref(pixbuf);
    }
 
