@@ -4,7 +4,7 @@
 *
 * Plots lines.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -42,7 +42,7 @@ void PlotLines ( void )
           axis_length, *p, origin[3], Ry[9], Rz[9], Ryz[9], r1[3], r2[3], 
           line_coords[6] = { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };
    char line[NLINE], *pchar, line_char, color_char;
-   extern char color_string[];   /* color-specification characters */
+   extern char color_string[];   /* color-specification characters "kaswrylqbfmogtnpx" */
    const char *error_str[] =
       { "Invalid or missing line coordinates.",
         "Invalid line color character.",
