@@ -4,7 +4,7 @@
 *
 * Plots a two-dimensional projection of three-dimensional points data.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -32,9 +32,12 @@
 void PlotPoints3d ( int iplot, int index, int npts )
    {
    /* Declare variables */
-   int i, j, nxvalues, nyvalues, nzvalues, index_stemflags;
+   int i, j, ifunc, nxvalues, nyvalues, nzvalues, index_stemflags;
    double phi, theta, axis_length, origin[3], Ry[9], Rz[9], Ryz[9], r[3], rstem[3], *p,
           xmin, xmax, ymin, ymax, zmin, zmax, xscale, yscale, zscale, x, y;
+   char *pchar;
+   extern char symbol_string1[];   /* symbol-specification characters "cCtTsSiIpPhH" */
+   extern char symbol_string2[];   /* symbol-specification characters "+xra" */
    GnomeCanvasPoints *points;
 
 
@@ -202,9 +205,10 @@ void PlotPoints3d ( int iplot, int index, int npts )
                          xscale, yscale, zscale, 'd');
 
 
-   /* Draw circles */
-   else if ( stylechar1[iplot-1] == 'c' || stylechar1[iplot-1] == 'C' )
+   /* Draw symbols in symbol_string1 ("cCtTsSiIpPhH") */
+   else if ( (pchar = strchr(symbol_string1, stylechar1[iplot-1])) != NULL )
       {
+      ifunc = pchar - symbol_string1;
       for ( i=1; i<=npts; i++ )
          if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
               ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
@@ -220,165 +224,16 @@ void PlotPoints3d ( int iplot, int index, int npts )
 
             x = origin[1] + r[1];
             y = origin[2] - r[2];
-
-            DrawCircle(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                       stylesizes[iplot-1]);
-            }
-      }
-  
-
-   /* Draw triangles */
-   else if ( stylechar1[iplot-1] == 't' || stylechar1[iplot-1] == 'T' )
-      {
-      for ( i=1; i<=npts; i++ )
-         if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
-              ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
-              zmin <= zdata[index+i-1] && zdata[index+i-1] <= zmax )
-            {
-            r[0] = (xdata[index+i-1] - xmin)*xscale;
-            r[1] = (ydata[index+i-1] - ymin)*yscale;
-            r[2] = (zdata[index+i-1] - zmin)*zscale;
-
-            p = multiply_mv(Ryz, r);
-            for ( j=1; j<=3; j++, p++ )
-               r[j-1] = *p;
-
-            x = origin[1] + r[1];
-            y = origin[2] - r[2];
-
-            DrawTriangle(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                         stylesizes[iplot-1]);
-            }
-      }
-  
-
-   /* Draw squares */
-   else if ( stylechar1[iplot-1] == 's' || stylechar1[iplot-1] == 'S' )
-      {
-      for ( i=1; i<=npts; i++ )
-         if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
-              ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
-              zmin <= zdata[index+i-1] && zdata[index+i-1] <= zmax )
-            {
-            r[0] = (xdata[index+i-1] - xmin)*xscale;
-            r[1] = (ydata[index+i-1] - ymin)*yscale;
-            r[2] = (zdata[index+i-1] - zmin)*zscale;
-
-            p = multiply_mv(Ryz, r);
-            for ( j=1; j<=3; j++, p++ )
-               r[j-1] = *p;
-
-            x = origin[1] + r[1];
-            y = origin[2] - r[2];
-
-            DrawSquare(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                       stylesizes[iplot-1]);
-            }
-      }
-  
-
-   /* Draw diamonds */
-   else if ( stylechar1[iplot-1] == 'i' || stylechar1[iplot-1] == 'I' )
-      {
-      for ( i=1; i<=npts; i++ )
-         if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
-              ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
-              zmin <= zdata[index+i-1] && zdata[index+i-1] <= zmax )
-            {
-            r[0] = (xdata[index+i-1] - xmin)*xscale;
-            r[1] = (ydata[index+i-1] - ymin)*yscale;
-            r[2] = (zdata[index+i-1] - zmin)*zscale;
-
-            p = multiply_mv(Ryz, r);
-            for ( j=1; j<=3; j++, p++ )
-               r[j-1] = *p;
-
-            x = origin[1] + r[1];
-            y = origin[2] - r[2];
-
-            DrawDiamond(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                        stylesizes[iplot-1]);
-            }
-      }
-  
-
-   /* Draw pentagons */
-   else if ( stylechar1[iplot-1] == 'p' || stylechar1[iplot-1] == 'P' )
-      {
-      for ( i=1; i<=npts; i++ )
-         if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
-              ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
-              zmin <= zdata[index+i-1] && zdata[index+i-1] <= zmax )
-            {
-            r[0] = (xdata[index+i-1] - xmin)*xscale;
-            r[1] = (ydata[index+i-1] - ymin)*yscale;
-            r[2] = (zdata[index+i-1] - zmin)*zscale;
-
-            p = multiply_mv(Ryz, r);
-            for ( j=1; j<=3; j++, p++ )
-               r[j-1] = *p;
-
-            x = origin[1] + r[1];
-            y = origin[2] - r[2];
-
-            DrawPentagon(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                         stylesizes[iplot-1]);
-            }
-      }
-  
-
-   /* Draw hexagons */
-   else if ( stylechar1[iplot-1] == 'h' || stylechar1[iplot-1] == 'H' )
-      {
-      for ( i=1; i<=npts; i++ )
-         if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
-              ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
-              zmin <= zdata[index+i-1] && zdata[index+i-1] <= zmax )
-            {
-            r[0] = (xdata[index+i-1] - xmin)*xscale;
-            r[1] = (ydata[index+i-1] - ymin)*yscale;
-            r[2] = (zdata[index+i-1] - zmin)*zscale;
-
-            p = multiply_mv(Ryz, r);
-            for ( j=1; j<=3; j++, p++ )
-               r[j-1] = *p;
-
-            x = origin[1] + r[1];
-            y = origin[2] - r[2];
-
-            DrawHexagon(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                        stylesizes[iplot-1]);
-            }
-      }
-  
-
-   /* Draw +'s */
-   else if ( stylechar1[iplot-1] == '+' )
-      {
-      for ( i=1; i<=npts; i++ )
-         if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
-              ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
-              zmin <= zdata[index+i-1] && zdata[index+i-1] <= zmax )
-            {
-            r[0] = (xdata[index+i-1] - xmin)*xscale;
-            r[1] = (ydata[index+i-1] - ymin)*yscale;
-            r[2] = (zdata[index+i-1] - zmin)*zscale;
-
-            p = multiply_mv(Ryz, r);
-            for ( j=1; j<=3; j++, p++ )
-               r[j-1] = *p;
-
-            x = origin[1] + r[1];
-            y = origin[2] - r[2];
-
-            DrawPlus(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+            symbol_func1[ifunc](x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+                                stylesizes[iplot-1]);
             }
       }
 
 
-   /* Draw 's */
-   else if ( stylechar1[iplot-1] == 'x' )
+   /* Draw symbols in symbol_string2 ("+xra") */
+   else if ( (pchar = strchr(symbol_string2, stylechar1[iplot-1])) != NULL )
       {
+      ifunc = pchar - symbol_string2;
       for ( i=1; i<=npts; i++ )
          if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
               ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
@@ -394,56 +249,7 @@ void PlotPoints3d ( int iplot, int index, int npts )
 
             x = origin[1] + r[1];
             y = origin[2] - r[2];
-
-            DrawX(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
-            }
-      }
-
-
-   /* Draw stars */
-   else if ( stylechar1[iplot-1] == 'r' )
-      {
-      for ( i=1; i<=npts; i++ )
-         if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
-              ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
-              zmin <= zdata[index+i-1] && zdata[index+i-1] <= zmax )
-            {
-            r[0] = (xdata[index+i-1] - xmin)*xscale;
-            r[1] = (ydata[index+i-1] - ymin)*yscale;
-            r[2] = (zdata[index+i-1] - zmin)*zscale;
-
-            p = multiply_mv(Ryz, r);
-            for ( j=1; j<=3; j++, p++ )
-               r[j-1] = *p;
-
-            x = origin[1] + r[1];
-            y = origin[2] - r[2];
-
-            DrawStar(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
-            }
-      }
-
-
-   /* Draw asterisks */
-   else if ( stylechar1[iplot-1] == 'a' )
-      {
-      for ( i=1; i<=npts; i++ )
-         if ( xmin <= xdata[index+i-1] && xdata[index+i-1] <= xmax &&
-              ymin <= ydata[index+i-1] && ydata[index+i-1] <= ymax &&
-              zmin <= zdata[index+i-1] && zdata[index+i-1] <= zmax )
-            {
-            r[0] = (xdata[index+i-1] - xmin)*xscale;
-            r[1] = (ydata[index+i-1] - ymin)*yscale;
-            r[2] = (zdata[index+i-1] - zmin)*zscale;
-
-            p = multiply_mv(Ryz, r);
-            for ( j=1; j<=3; j++, p++ )
-               r[j-1] = *p;
-
-            x = origin[1] + r[1];
-            y = origin[2] - r[2];
-
-            DrawAsterisk(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+            symbol_func2[ifunc](x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
             }
       }
 
