@@ -4,7 +4,7 @@
 *
 * Plots symbols.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -25,6 +25,7 @@
 *******************************************************************************/
 
 
+#include <ctype.h>
 #include <math.h>
 #include "gsegraf.h"
 
@@ -32,7 +33,7 @@
 void PlotSymbols ( void )
    {
    /* Declare variables */
-   int i, nx, ny, nz, ncoords, window_width, window_height;
+   int i, ifunc, nx, ny, nz, ncoords, window_width, window_height;
    unsigned int index, symbol_size;
    guint32 symbol_color;
    double x1_box, x2_box, y1_box, y2_box,
@@ -42,7 +43,9 @@ void PlotSymbols ( void )
           axis_length, *p, origin[3], Ry[9], Rz[9], Ryz[9], r[3],
           symbol_coords[3] = { 0.0, 0.0, 0.0 }, x, y;
    char line[NLINE], *pchar, symbol_char, color_char;
-   extern char color_string[];   /* color-specification characters */
+   extern char symbol_string1[];   /* symbol-specification characters "cCtTsSiIpPhH" */
+   extern char symbol_string2[];   /* symbol-specification characters "+xra" */
+   extern char color_string[];     /* color-specification characters "kaswrylqbfmogtnpx" */
    const char *error_str[] =
       { "Invalid or missing symbol coordinates.",
         "Invalid symbol color character.",
@@ -395,53 +398,22 @@ void PlotSymbols ( void )
                continue;
             }
 
-         if ( symbol_char == 'c' )
-            DrawCircle(x, y, color_rgba[3], symbol_color, symbol_size);
+         /* Draw symbols in symbol_string1 ("cCtTsSiIpPhH") */
+         if ( (pchar = strchr(symbol_string1, symbol_char)) != NULL )
+            {
+            ifunc = pchar - symbol_string1;
+            if ( isupper(*pchar) == 0 )
+               symbol_func1[ifunc](x, y, color_rgba[3], symbol_color, symbol_size);
+            else
+               symbol_func1[ifunc](x, y, symbol_color, symbol_color, symbol_size);
+            }
 
-         else if ( symbol_char == 'C' )
-            DrawCircle(x, y, symbol_color, symbol_color, symbol_size);
-
-         else if ( symbol_char == 't' )
-            DrawTriangle(x, y, color_rgba[3], symbol_color, symbol_size);
-
-         else if ( symbol_char == 'T' )
-            DrawTriangle(x, y, symbol_color, symbol_color, symbol_size);
-
-         else if ( symbol_char == 's' )
-            DrawSquare(x, y, color_rgba[3], symbol_color, symbol_size);
-
-         else if ( symbol_char == 'S' )
-            DrawSquare(x, y, symbol_color, symbol_color, symbol_size);
-
-         else if ( symbol_char == 'i' )
-            DrawDiamond(x, y, color_rgba[3], symbol_color, symbol_size);
-
-         else if ( symbol_char == 'I' )
-            DrawDiamond(x, y, symbol_color, symbol_color, symbol_size);
-
-         else if ( symbol_char == 'p' )
-            DrawPentagon(x, y, color_rgba[3], symbol_color, symbol_size);
-
-         else if ( symbol_char == 'P' )
-            DrawPentagon(x, y, symbol_color, symbol_color, symbol_size);
-
-         else if ( symbol_char == 'h' )
-            DrawHexagon(x, y, color_rgba[3], symbol_color, symbol_size);
-
-         else if ( symbol_char == 'H' )
-            DrawHexagon(x, y, symbol_color, symbol_color, symbol_size);
-
-         else if ( symbol_char == '+' )
-            DrawPlus(x, y, symbol_color, symbol_size);
-
-         else if ( symbol_char == 'x' )
-            DrawX(x, y, symbol_color, symbol_size);
-
-         else if ( symbol_char == 'r' )
-            DrawStar(x, y, symbol_color, symbol_size);
-
-         else if ( symbol_char == 'a' )
-            DrawAsterisk(x, y, symbol_color, symbol_size);
+         /* Draw symbols in symbol_string2 ("+xra") */
+         else if ( (pchar = strchr(symbol_string2, symbol_char)) != NULL )
+            {
+            ifunc = pchar - symbol_string2;
+            symbol_func2[ifunc](x, y, symbol_color, symbol_size);
+            }
          }
 
       else if ( strncmp(line, "*****", 5) == 0 )
