@@ -4,7 +4,7 @@
 *
 * Calculates polar plot of input data.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -33,12 +33,14 @@
 void PolarPlot ( void )
    {
    /* Declare variables */
-   int i, nyvalues, nrvalues, iplot, nplots, npts, index, index_stemflags,
+   int i, j, ifunc, nyvalues, nrvalues, iplot, nplots, npts, index, index_stemflags,
        anchor, window_width, window_height;
    double rmin, rmax, xorigin, yorigin, radius, radius_grid, rscale,
           x, y, x1, y1, x2, y2, xtext1, xtext2, ytext1, ytext2,
-          theta, theta_max, r, r1, width_xtick_label;
-   char tick_label[4];
+          theta, theta_max, theta_minor, r, r1, dr, width_xtick_label;
+   char string[21], *pchar;
+   extern char symbol_string1[];   /* symbol-specification characters "cCtTsSiIpPhH" */
+   extern char symbol_string2[];   /* symbol-specification characters "+xra" */
    GnomeCanvasPoints *points;
    GnomeCanvasItem *line, *circle, *rectangle, *text, *pixbuf_item;
 
@@ -135,7 +137,7 @@ void PolarPlot ( void )
       points = gnome_canvas_points_new(2);
       for ( i=1; i<=12; i++ )
          {
-         theta = (i - 1.0)*30.0*deg2rad;
+         theta = (i - 1)*30.0*deg2rad;
          points->coords[0] = xorigin + radius*cos(theta);
          points->coords[1] = yorigin - radius*sin(theta);
          points->coords[2] = xorigin + (radius - tick_major)*cos(theta);
@@ -147,11 +149,59 @@ void PolarPlot ( void )
                                       "fill_color_rgba", 0x000000FF,
                                       "width_pixels", 1,
                                       NULL);
+
+         if ( minor_ticks_flag == 1 )
+            {
+            for ( j=1; j<=5; j++ )
+               {
+               theta_minor = ((i - 1)*30.0 + j*5.0)*deg2rad;
+               points->coords[0] = xorigin + radius*cos(theta_minor);
+               points->coords[1] = yorigin - radius*sin(theta_minor);
+               points->coords[2] = xorigin + (radius - tick_minor)*cos(theta_minor);
+               points->coords[3] = yorigin - (radius - tick_minor)*sin(theta_minor);
+
+               line = gnome_canvas_item_new(group,
+                                            GNOME_TYPE_CANVAS_LINE,
+                                            "points", points,
+                                            "fill_color_rgba", 0x000000FF,
+                                            "width_pixels", 1,
+                                            NULL);
+               }
+            }
          }
       gnome_canvas_points_unref(points);
       }
 
 
+   /* Draw r axis and tick marks */
+   if ( strcmp(p_plot_param->plot_box, "on") == 0 &&
+        strcmp(p_plot_param->y_tick_marks, "on") == 0 )
+      {
+      points = gnome_canvas_points_new(2);
+
+      theta = 45.0*deg2rad;
+      points->coords[0] = xorigin;
+      points->coords[1] = yorigin;
+      points->coords[2] = xorigin + radius*cos(theta);
+      points->coords[3] = yorigin - radius*sin(theta);
+
+      line = gnome_canvas_item_new(group,
+                                   GNOME_TYPE_CANVAS_LINE,
+                                   "points", points,
+                                   "fill_color_rgba", 0x000000FF,
+                                   "width_pixels", 1,
+                                   NULL);
+
+      DrawTickMarks("linear", minor_ticks_flag, 1,
+                    xorigin, yorigin, xorigin + radius*cos(45.0*deg2rad), yorigin - radius*sin(theta),
+                    p_ticklabels->nyvalues, &p_ticklabels->yvalues[0],
+                    p_ticklabels->yoffset1, p_ticklabels->yoffset2,
+                    135.0*deg2rad);
+
+      gnome_canvas_points_unref(points);
+      }
+
+
    /* Draw plot circle */
    if ( strcmp(p_plot_param->plot_box, "on") == 0 )
       circle = gnome_canvas_item_new(group,
@@ -177,7 +227,8 @@ void PolarPlot ( void )
          theta = (i - 1.0)*30.0*deg2rad;
          x = xorigin + (radius + 8.0)*cos(theta);
          y = yorigin - (radius + 8.0)*sin(theta);
-         sprintf(tick_label, "%d", (i - 1)*30);
+         memset(string, 0, strlen(string));
+         sprintf(string, "%d", (i - 1)*30);
 
          if ( i == 1 )
             anchor = GTK_ANCHOR_WEST;
@@ -198,7 +249,7 @@ void PolarPlot ( void )
 
          text = gnome_canvas_item_new(group,
                                       GNOME_TYPE_CANVAS_TEXT,
-                                      "text", tick_label,
+                                      "text", string,
                                       "x", x,
                                       "y", y,
                                       "anchor", anchor,
@@ -389,9 +440,10 @@ void PolarPlot ( void )
          DrawLineSegmentsPolar(iplot, index, npts, xorigin, yorigin, rmin, rmax, rscale, 'd');
 
 
-      /* Draw circles */
-      else if ( stylechar1[iplot-1] == 'c' || stylechar1[iplot-1] == 'C' )
+      /* Draw symbols in symbol_string1 ("cCtTsSiIpPhH") */
+      else if ( (pchar = strchr(symbol_string1, stylechar1[iplot-1])) != NULL )
          {
+         ifunc = pchar - symbol_string1;
          for ( i=1; i<=npts; i++ )
             {
             theta = xdata[index+i-1];
@@ -400,17 +452,17 @@ void PolarPlot ( void )
                {
                x = xorigin + (r - rmin)*cos(theta)*rscale;
                y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawCircle(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                          stylesizes[iplot-1]);
+               symbol_func1[ifunc](x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
+                                   stylesizes[iplot-1]);
                }
             }
          }
 
 
-      /* Draw triangles */
-      else if ( stylechar1[iplot-1] == 't' || stylechar1[iplot-1] == 'T' )
+      /* Draw symbols in symbol_string2 ("+xra") */
+      else if ( (pchar = strchr(symbol_string2, stylechar1[iplot-1])) != NULL )
          {
+         ifunc = pchar - symbol_string2;
          for ( i=1; i<=npts; i++ )
             {
             theta = xdata[index+i-1];
@@ -419,157 +471,7 @@ void PolarPlot ( void )
                {
                x = xorigin + (r - rmin)*cos(theta)*rscale;
                y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawTriangle(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                            stylesizes[iplot-1]);
-               }
-            }
-         }
-
-
-      /* Draw squares */
-      else if ( stylechar1[iplot-1] == 's' || stylechar1[iplot-1] == 'S' )
-         {
-         for ( i=1; i<=npts; i++ )
-            {
-            theta = xdata[index+i-1];
-            r     = ydata[index+i-1];
-            if ( rmin <= r && r <= rmax )
-               {
-               x = xorigin + (r - rmin)*cos(theta)*rscale;
-               y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawSquare(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                          stylesizes[iplot-1]);
-               }
-            }
-         }
-
-
-      /* Draw diamonds */
-      else if ( stylechar1[iplot-1] == 'i' || stylechar1[iplot-1] == 'I' )
-         {
-         for ( i=1; i<=npts; i++ )
-            {
-            theta = xdata[index+i-1];
-            r     = ydata[index+i-1];
-            if ( rmin <= r && r <= rmax )
-               {
-               x = xorigin + (r - rmin)*cos(theta)*rscale;
-               y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawDiamond(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                           stylesizes[iplot-1]);
-               }
-            }
-         }
-
-
-      /* Draw pentagons */
-      else if ( stylechar1[iplot-1] == 'p' || stylechar1[iplot-1] == 'P' )
-         {
-         for ( i=1; i<=npts; i++ )
-            {
-            theta = xdata[index+i-1];
-            r     = ydata[index+i-1];
-            if ( rmin <= r && r <= rmax )
-               {
-               x = xorigin + (r - rmin)*cos(theta)*rscale;
-               y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawPentagon(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                            stylesizes[iplot-1]);
-               }
-            }
-         }
-
-
-      /* Draw hexagons */
-      else if ( stylechar1[iplot-1] == 'h' || stylechar1[iplot-1] == 'H' )
-         {
-         for ( i=1; i<=npts; i++ )
-            {
-            theta = xdata[index+i-1];
-            r     = ydata[index+i-1];
-            if ( rmin <= r && r <= rmax )
-               {
-               x = xorigin + (r - rmin)*cos(theta)*rscale;
-               y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawHexagon(x, y, fill_colors_rgba[iplot-1], outline_colors_rgba[iplot-1],
-                           stylesizes[iplot-1]);
-               }
-            }
-         }
-
-
-      /* Draw +'s */
-      else if ( stylechar1[iplot-1] == '+' )
-         {
-         for ( i=1; i<=npts; i++ )
-            {
-            theta = xdata[index+i-1];
-            r     = ydata[index+i-1];
-            if ( rmin <= r && r <= rmax )
-               {
-               x = xorigin + (r - rmin)*cos(theta)*rscale;
-               y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawPlus(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
-               }
-            }
-         }
-
-
-      /* Draw 's */
-      else if ( stylechar1[iplot-1] == 'x' )
-         {
-         for ( i=1; i<=npts; i++ )
-            {
-            theta = xdata[index+i-1];
-            r     = ydata[index+i-1];
-            if ( rmin <= r && r <= rmax )
-               {
-               x = xorigin + (r - rmin)*cos(theta)*rscale;
-               y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawX(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
-               }
-            }
-         }
-
-
-      /* Draw stars */
-      else if ( stylechar1[iplot-1] == 'r' )
-         {
-         for ( i=1; i<=npts; i++ )
-            {
-            theta = xdata[index+i-1];
-            r     = ydata[index+i-1];
-            if ( rmin <= r && r <= rmax )
-               {
-               x = xorigin + (r - rmin)*cos(theta)*rscale;
-               y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawStar(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
-               }
-            }
-         }
-
-
-      /* Draw asterisks */
-      else if ( stylechar1[iplot-1] == 'a' )
-         {
-         for ( i=1; i<=npts; i++ )
-            {
-            theta = xdata[index+i-1];
-            r     = ydata[index+i-1];
-            if ( rmin <= r && r <= rmax )
-               {
-               x = xorigin + (r - rmin)*cos(theta)*rscale;
-               y = yorigin - (r - rmin)*sin(theta)*rscale;
-
-               DrawAsterisk(x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
+               symbol_func2[ifunc](x, y, fill_colors_rgba[iplot-1], stylesizes[iplot-1]);
                }
             }
          }
@@ -588,20 +490,25 @@ void PolarPlot ( void )
         strcmp(p_plot_param->y_tick_marks, "on")  == 0 &&
         strcmp(p_plot_param->y_tick_labels, "on") == 0 )
       {
+      dr = (rmax - rmin)/(nrvalues - 1);
       for ( i=1; i<=nrvalues; i++ )
          {
          theta = 45.0*deg2rad;
          x = xorigin + (p_ticklabels->yvalues[i-1] - rmin)*rscale*cos(theta);
          y = yorigin - (p_ticklabels->yvalues[i-1] - rmin)*rscale*sin(theta);
 
-         sprintf(tick_label, "%g", p_ticklabels->yvalues[i-1]);
+         memset(string, 0, strlen(string));
+         if ( fabs(p_ticklabels->yvalues[i-1]) < 0.01*dr )
+            sprintf(string, "%1.0f", 0.0);
+         else
+            sprintf(string, "%g", p_ticklabels->yvalues[i-1]);
 
          text = gnome_canvas_item_new(group,
                                       GNOME_TYPE_CANVAS_TEXT,
-                                      "text", tick_label,
-                                      "x", x,
+                                      "text", string,
+                                      "x", x - 10.0,
                                       "y", y,
-                                      "anchor", GTK_ANCHOR_NORTH_EAST,
+                                      "anchor", GTK_ANCHOR_EAST,
                                       "font-desc", font_tick_labels,
                                       "fill_color_rgba", 0x000000FF,
                                       NULL);
@@ -614,8 +521,8 @@ void PolarPlot ( void )
                                            "x2", xtext2,
                                            "y1", ytext1,
                                            "y2", ytext2,
-                                           "fill_color_rgba", 0xFFFFFF80,
-                                           "outline_color_rgba", 0xFFFFFF80,
+                                           "fill_color_rgba", 0xFFFFFFC0,
+                                           "outline_color_rgba", 0xFFFFFFC0,
                                            "width_pixels", 1,
                                            NULL);
 
