@@ -4,7 +4,7 @@
 *
 * Reads plot-parameter file.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -35,22 +35,24 @@ void ReadParamFile ( void )
    /* Declare variables */
    int i, j, iplot, nplots, iformat, nformat, nfilenames_total, nformats_total,
        index_filenames, index_formats, index_plot_types, index_bin_values,
-       index_bin_refs, ibinwidth, index_stemflags, ibinvalue, ibinref, istemflag,
-       stylesize;
+       index_bin_refs, ibinwidth, index_stemflags, ibinvalue, ibinref, ininterp,
+       istemflag, imeshcolor, icontourcolor, stylesize;
    unsigned int index, size;
    char line[NLINE], *string, *pchar, character;
-   extern char color_string[];   /* color-specification characters */
+   extern char color_string[];   /* color-specification characters "kaswrylqbfmogtnpx" */
    const char *error_str[] =
       { "Missing file_name data.",
         "Missing file_format data.",
         "Invalid or missing axis_type parameter.",
         "Invalid or missing plot_type parameter.",
-        "Invalid plot_style parameter.",
         "Invalid axis_limits parameter.",
-        "Invalid grid parameter.",
         "Invalid or incomplete view direction angles.",
+        "Invalid grid parameter.",
         "Invalid histogram bin width.",
+        "Invalid ninterp value.",
         "Invalid contours value.",
+        "Invalid or missing contour color.",
+        "Invalid or missing mesh color.",
         "Invalid window-size data;\ntwo integers required.",
         "Invalid or missing date-time font size.",
         "Invalid or missing legend font size.",
@@ -190,8 +192,11 @@ void ReadParamFile ( void )
    bin_widths          = malloc(nplots*sizeof(double));
    bin_values          = malloc(9*nplots*sizeof(char));
    bin_refs            = malloc(9*nplots*sizeof(char));
+   ninterp             = malloc(nplots*sizeof(int));
    stemflags           = malloc(4*nplots*sizeof(char));
    stemvalues          = malloc(nplots*sizeof(double));
+   meshcolors          = malloc(nplots*sizeof(guint32));
+   contourcolors       = malloc(nplots*sizeof(guint32));
    ndata               = malloc(nplots*sizeof(int));
    memset(filenames,   0, nfilenames_total*sizeof(char));
    memset(formats,     0, nformats_total*sizeof(char));
@@ -235,9 +240,24 @@ void ReadParamFile ( void )
 
 
    /* Set default number of contours */
+   /* (2d and 3d contour plots) */
    ncontours = 0;
 
 
+   /* Set default number of interpolation intervals */
+   /* (3d color plots) */
+   for ( i=1; i<=nplots; i++ )
+      ninterp[i-1] = 20;
+
+
+   /* Set default 3d-mesh colors and 3d-contour colors */
+   for ( i=1; i<=nplots; i++ )
+      {
+      meshcolors[i-1] = 0x000000FF;
+      contourcolors[i-1] = 0x000000FF;
+      }
+
+
    /* Read filenames */
    iplot = 0;
    index_filenames = 0;
@@ -425,7 +445,8 @@ void ReadParamFile ( void )
                   }
                }
 
-            else if ( strcmp(&plot_types[index_plot_types], "color") == 0 )
+            else if ( strcmp(&plot_types[index_plot_types], "color") == 0 &&
+                      strcmp(p_plot_param->axis_type, "linear") == 0 )
                {
                size = strlen(&line[10]);
                if ( (string = get_string(&line[10], &size)) != NULL )
@@ -501,16 +522,18 @@ void ReadParamFile ( void )
                }
 
             else if ( (strcmp(&plot_types[index_plot_types], "contour") == 0 ||
+                       strcmp(&plot_types[index_plot_types], "color")   == 0 ||
                        strcmp(&plot_types[index_plot_types], "mesh")    == 0) &&
                       strcmp(p_plot_param->axis_type, "3d") == 0 )
                {
                size = strlen(&line[10]);
-               if ( strcmp(&plot_types[index_plot_types], "mesh") == 0 &&
+               if ( (strcmp(&plot_types[index_plot_types], "color") == 0 ||
+                     strcmp(&plot_types[index_plot_types], "mesh")  == 0) &&
                     (string = get_string(&line[10], &size)) != NULL )
                   {
                   /************************************************************
                   *
-                  * 3d mesh plot type
+                  * 3d color and 3d mesh plot types
                   * Read "auto" string and color alpha value
                   *
                   ************************************************************/
@@ -589,11 +612,14 @@ void ReadParamFile ( void )
    /* Read remainder of plot-parameter file */
    ibinwidth = 0;
    ibinvalue = 0;
-   ibinref   = 0;
+   ibinref = 0;
+   ininterp = 0;
    istemflag = 0;
+   imeshcolor = 0;
+   icontourcolor = 0;
    index_bin_values = 0;
-   index_bin_refs   = 0;
-   index_stemflags  = 0;
+   index_bin_refs = 0;
+   index_stemflags = 0;
    rewind(fptr);
    while ( fgets(line, sizeof(line), fptr) != NULL )
       {
@@ -621,7 +647,7 @@ void ReadParamFile ( void )
                   break;
                else if ( character != '*' )
                   {
-                  ErrorDialog(error_str[5]);
+                  ErrorDialog(error_str[4]);
                   FreeMemory();
                   exit(1);
                   }
@@ -638,12 +664,23 @@ void ReadParamFile ( void )
          {
          if ( sscanf(&line[6], "%lf %lf", &p_plot_param_3d->phi, &p_plot_param_3d->theta) != 2 )
             {
-            ErrorDialog(error_str[7]);
+            ErrorDialog(error_str[5]);
             FreeMemory();
             exit(1);
             }
          }
 
+      else if ( strncmp(line, "minor_ticks", 11) == 0 )
+         {
+         size = strlen(&line[11]);
+         if ( (string = get_string(&line[11], &size)) != NULL )
+            {
+            strncpy(&p_plot_param->minor_ticks[0], string, 3);
+            if ( strcmp(string, "on") == 0 )
+               minor_ticks_flag = 1;
+            }
+         }
+
       else if ( strncmp(line, "grid", 4) == 0 )
          {
          size = strlen(&line[4]);
@@ -718,7 +755,7 @@ void ReadParamFile ( void )
          if ( ibinwidth <= nplots )
             if ( sscanf(&line[9], "%lf", &bin_widths[ibinwidth-1]) != 1 )
                {
-               ErrorDialog(error_str[8]);
+               ErrorDialog(error_str[7]);
                FreeMemory();
                exit(1);
                }
@@ -752,6 +789,18 @@ void ReadParamFile ( void )
             }
          }
 
+      else if ( strncmp(line, "ninterp", 7) == 0 )
+         {
+         ininterp++;
+         if ( ininterp <= nplots )
+            if ( sscanf(&line[7], "%d", &ninterp[ininterp-1]) != 1 )
+               {
+               ErrorDialog(error_str[8]);
+               FreeMemory();
+               exit(1);
+               }
+         }
+
       else if ( strncmp(line, "contours", 8) == 0 )
          {
          if ( sscanf(&line[8], "%d", &ncontours) != 1 )
@@ -762,6 +811,54 @@ void ReadParamFile ( void )
             }
          }
 
+      else if ( strncmp(line, "contour_color", 13) == 0 )
+         {
+         icontourcolor++;
+         if ( icontourcolor <= nplots )
+            {
+            if ( sscanf(&line[13], " 0x%x", (unsigned int *) &contourcolors[icontourcolor-1]) != 1 &&
+                 sscanf(&line[13], " 0X%x", (unsigned int *) &contourcolors[icontourcolor-1]) != 1 )
+               {
+               if ( sscanf(&line[13], " %c", &character) == 1 &&
+                    (pchar = strchr(color_string, character)) != NULL )
+                  {
+                  index = pchar - &color_string[0];                     /* get index to color character */
+                  contourcolors[icontourcolor-1] = color_rgba[index];   /* set specified color */
+                  }
+               else
+                  {
+                  ErrorDialog(error_str[10]);
+                  FreeMemory();
+                  exit(1);
+                  }
+               }
+            }
+         }
+
+      else if ( strncmp(line, "mesh_color", 10) == 0 )
+         {
+         imeshcolor++;
+         if ( imeshcolor <= nplots )
+            {
+            if ( sscanf(&line[10], " 0x%x", (unsigned int *) &meshcolors[imeshcolor-1]) != 1 &&
+                 sscanf(&line[10], " 0X%x", (unsigned int *) &meshcolors[imeshcolor-1]) != 1 )
+               {
+               if ( sscanf(&line[10], " %c", &character) == 1 &&
+                    (pchar = strchr(color_string, character)) != NULL )
+                  {
+                  index = pchar - &color_string[0];               /* get index to color character */
+                  meshcolors[imeshcolor-1] = color_rgba[index];   /* set specified color */
+                  }
+               else
+                  {
+                  ErrorDialog(error_str[11]);
+                  FreeMemory();
+                  exit(1);
+                  }
+               }
+            }
+         }
+
       else if ( strncmp(line, "stems", 5) == 0 )
          {
          istemflag++;
@@ -806,7 +903,7 @@ void ReadParamFile ( void )
             {
             save_filename = malloc(size + 1);
             strcpy(save_filename, string);
-            flag_close = 1;
+            close_flag = 1;
             }
          }
 
@@ -873,7 +970,7 @@ void ReadParamFile ( void )
          {
          if ( sscanf(&line[11], "%d %d", &p_window_data->width, &p_window_data->height ) != 2 )
             {
-            ErrorDialog(error_str[10]);
+            ErrorDialog(error_str[12]);
             FreeMemory();
             exit(1);
             }
@@ -894,7 +991,7 @@ void ReadParamFile ( void )
          {
          if ( sscanf(&line[19], "%lf", &font_size_date_time) != 1 )
             {
-            ErrorDialog(error_str[11]);
+            ErrorDialog(error_str[13]);
             FreeMemory();
             exit(1);
             }
@@ -904,7 +1001,7 @@ void ReadParamFile ( void )
          {
          if ( sscanf(&line[16], "%lf", &font_size_legend) != 1 )
             {
-            ErrorDialog(error_str[12]);
+            ErrorDialog(error_str[14]);
             FreeMemory();
             exit(1);
             }
@@ -914,7 +1011,7 @@ void ReadParamFile ( void )
          {
          if ( sscanf(&line[14], "%lf", &font_size_text) != 1 )
             {
-            ErrorDialog(error_str[13]);
+            ErrorDialog(error_str[15]);
             FreeMemory();
             exit(1);
             }
@@ -924,7 +1021,7 @@ void ReadParamFile ( void )
          {
          if ( sscanf(&line[21], "%lf", &font_size_tick_labels) != 1 )
             {
-            ErrorDialog(error_str[14]);
+            ErrorDialog(error_str[16]);
             FreeMemory();
             exit(1);
             }
@@ -934,7 +1031,7 @@ void ReadParamFile ( void )
          {
          if ( sscanf(&line[21], "%lf", &font_size_axis_labels) != 1 )
             {
-            ErrorDialog(error_str[15]);
+            ErrorDialog(error_str[17]);
             FreeMemory();
             exit(1);
             }
@@ -944,7 +1041,7 @@ void ReadParamFile ( void )
          {
          if ( sscanf(&line[15], "%lf", &font_size_title) != 1 )
             {
-            ErrorDialog(error_str[16]);
+            ErrorDialog(error_str[18]);
             FreeMemory();
             exit(1);
             }
@@ -964,7 +1061,7 @@ void ReadParamFile ( void )
             {
             if ( p_plot_param->axis_limits[i-1] <= 0.0 )
                {
-               ErrorDialog(error_str[17]);
+               ErrorDialog(error_str[19]);
                FreeMemory();
                exit(1);
                }
@@ -979,7 +1076,7 @@ void ReadParamFile ( void )
             {
             if ( p_plot_param->axis_limits[i-1] <= 0.0 )
                {
-               ErrorDialog(error_str[18]);
+               ErrorDialog(error_str[20]);
                FreeMemory();
                exit(1);
                }
@@ -994,7 +1091,7 @@ void ReadParamFile ( void )
             {
             if ( p_plot_param->axis_limits[i-1] <= 0.0 )
                {
-               ErrorDialog(error_str[19]);
+               ErrorDialog(error_str[21]);
                FreeMemory();
                exit(1);
                }
