@@ -4,7 +4,7 @@
 *
 * Causes plot to zoom to indicated rectangle.
 *
-* Copyright  2008 Spencer A. Buckner
+* Copyright  2008-2009 Spencer A. Buckner
 * http://savannah.gnu.org/projects/gsegrafix
 *
 * This file is part of GSEGrafix, a scientific and engineering plotting program.
@@ -126,9 +126,9 @@ void ZoomIn ( double x1_window, double y1_window, double x2_window, double y2_wi
       if ( strcmp(p_plot_param->axis_type, "linear") == 0 &&
            strcmp(p_plot_param->axis_scale, "equal") == 0 )
          AxesEqual(0);
-      DrawGrid();
+      DrawGrid2d();
       DrawGridLog();
-      PlotData();
+      PlotData2d();
       if ( strcmp(p_plot_param->axis_type, "linear") == 0 )
          {
          PlotRectangles();
@@ -136,7 +136,7 @@ void ZoomIn ( double x1_window, double y1_window, double x2_window, double y2_wi
          }
       PlotLines();
       PlotSymbols();
-      DrawTickLabels();
+      DrawTickLabels2d();
       DrawTickLabelsLog();
       DrawAxisLabels();
       DrawLegend();
